UrlContainer
============

.. currentmodule:: wwt_data_formats.abcs

.. autoclass:: UrlContainer
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~UrlContainer.mutate_urls

   .. rubric:: Methods Documentation

   .. automethod:: mutate_urls
